@@ -1,4 +1,4 @@
-package NewFangle 0.02 {
+package NewFangle 0.03 {
 
   use strict;
   use warnings;
@@ -16,6 +16,16 @@ package NewFangle 0.02 {
   $ffi->attach( newrelic_configure_log => ['string','newrelic_loglevel_t' ] => 'bool'   );
   $ffi->attach( newrelic_init          => ['string','int' ]                 => 'bool'   );
   $ffi->attach( newrelic_version       => []                                => 'string' );
+
+  if($ffi->find_symbol( 'newrelic_set_hostname' ))
+  {
+    $ffi->attach( newrelic_set_hostname => ['string'] => 'int' );
+  }
+  else
+  {
+    *newrelic_set_hostname = sub { 0 };
+  }
+
   $ffi->mangler(sub { "newrelic_$_[0]" });
 
   our @EXPORT_OK = grep /^newrelic_/, keys %NewFangle::;
@@ -36,7 +46,7 @@ NewFangle - Unofficial Perl NewRelic SDK
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -101,7 +111,22 @@ Initialize the C SDK with non-default settings.
 
 (csdk: newrelic_version)
 
-Returns the
+Returns the version of the NewRelic C-SDK as a string.
+
+=head2 newrelic_set_hostname
+
+ my $bool = newrelic_set_hostname($hostname);
+
+Sets the default hostname to be used in the NewRelic UI.  This is the result of
+C<gethostname> by default, but that might not be usefully meaningful when running in
+a docker or similar container.
+
+This requires a properly patched NewRelic C-SDK to work, since the base C-SDK doesn't
+currently support setting the language or version.  If you installed with L<Alien::libnewrelic>
+then it should have been properly patched for you.
+
+Returns true if successful, false otherwise.  Normally a failure would only happen if
+the NewRelic C-SDK hadn't been patched.
 
 =head1 ENVIRONMENT
 
@@ -115,6 +140,11 @@ The default app name, if not specified in the configuration.
 
 The NewRelic license key.
 
+=item C<NEWRELIC_APP_HOSTNAME>
+
+The host display name that will be reported to NewRelic, if the C<libnewrelic> has been properly
+patched (see C<newrelic_set_hostname> above).
+
 =back
 
 =head1 CAVEATS
