@@ -1,4 +1,4 @@
-package NewFangle::FFI 0.02 {
+package NewFangle::FFI 0.03 {
 
   use strict;
   use warnings;
@@ -13,14 +13,18 @@ package NewFangle::FFI 0.02 {
 # ABSTRACT: Private class for NewFangle.pm
 
 
+  sub _lib {
+    my $lib = FFI::CheckLib::find_lib lib => 'newrelic';
+    $lib
+      ? $lib
+      : FFI::CheckLib::find_lib lib => 'newrelic', alien => 'Alien::libnewrelic'
+    ;
+  }
+
+
   our $ffi = FFI::Platypus->new(
     api => 1,
-    lib => [do {
-      my $lib = FFI::CheckLib::find_lib lib => 'newrelic';
-      $lib
-        ? $lib
-        : FFI::CheckLib::find_lib lib => 'newrelic', alien => 'Alien::libnewrelic',
-    }],
+    lib => [_lib],
   );
   $ffi->mangler(sub { "newrelic_$_[0]" });
   $ffi->load_custom_type('::PtrObject', 'newrelic_segment_t', 'NewFangle::Segment',
@@ -33,7 +37,7 @@ package NewFangle::FFI 0.02 {
 
   FFI::C->ffi($ffi);
 
-  package NewFangle::NewrelicLoglevel 0.02 {
+  package NewFangle::NewrelicLoglevel 0.03 {
     FFI::C->enum([
       'error',
       'warning',
@@ -42,14 +46,14 @@ package NewFangle::FFI 0.02 {
     ], { prefix => 'NEWRELIC_LOG_' });
   }
 
-  package NewFangle::NewrelicTransactionTracerThreshold 0.02 {
+  package NewFangle::NewrelicTransactionTracerThreshold 0.03 {
     FFI::C->enum([
       'is_apdex_failing',
       'is_over_duration',
     ], { prefix => 'NEWRELIC_THRESHOLD_' });
   }
 
-  package NewFangle::NewrelicTtRecordsql 0.02 {
+  package NewFangle::NewrelicTtRecordsql 0.03 {
     FFI::C->enum([
       'off',
       'raw',
@@ -57,7 +61,7 @@ package NewFangle::FFI 0.02 {
     ], { prefix => 'NEWRELIC_SQL_' });
   }
 
-  package NewFangle::DatastoreReporting 0.02 {
+  package NewFangle::DatastoreReporting 0.03 {
     FFI::C->struct([
       enabled      => 'bool',
       record_sql   => 'newrelic_tt_recordsql_t',
@@ -65,7 +69,7 @@ package NewFangle::FFI 0.02 {
     ]);
   };
 
-  package NewFangle::NewrelicTransactionTracerConfig 0.02 {
+  package NewFangle::NewrelicTransactionTracerConfig 0.03 {
     FFI::C->struct([
       enabled                  => 'bool',
       threshold                => 'newrelic_transaction_tracer_threshold_t',
@@ -75,26 +79,26 @@ package NewFangle::FFI 0.02 {
     ]);
   }
 
-  package NewFangle::NewrelicDatastoreSegmentConfig 0.02 {
+  package NewFangle::NewrelicDatastoreSegmentConfig 0.03 {
     FFI::C->struct([
       instance_reporting      => 'bool',
       database_name_reporting => 'bool',
     ]);
   }
 
-  package NewFangle::NewrelicDistributedTracingConfig 0.02 {
+  package NewFangle::NewrelicDistributedTracingConfig 0.03 {
     FFI::C->struct([
       enabled => 'bool',
     ]);
   }
 
-  package NewFangle::NewrelicSpanEventConfig 0.02 {
+  package NewFangle::NewrelicSpanEventConfig 0.03 {
     FFI::C->struct([
       enabled => 'bool',
     ]);
   }
 
-  package NewFangle::NewrelicAppConfig 0.02 {
+  package NewFangle::NewrelicAppConfig 0.03 {
     FFI::C->struct([
       app_name            => 'string(255)',
       license_key         => 'string(255)',
@@ -124,7 +128,7 @@ NewFangle::FFI - Private class for NewFangle.pm
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
